# work in progress

## define rules for loading data and automatically apply it when loading the data in looker

### intended features
- write rules for how to format columns
- write rules for generating derived columns and measures
- refresh tables using cicd
- leverage llm to translate names and descriptions using locales, in a editable way